#!/usr/bin/perl
#
# urlSize version 1.0.0
#
# A real simple Perl function to determine the file size of an HTTP URL.
# This doesn't work with other types of URL such as FTP, FILE, LDAP, etc.
# A file size of -1 indicates that a connection could not be established
# with the remote server.
#
# http://www.ncc.com/freeware/
#
# Copyright (c) 1999, 2000 by R. Steven Rainwater <rsr@ncc.com>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#==========================================================================
use strict;
use Socket;
use FileHandle;

# Sample use of urlSize
print "\n", urlSize('http://www.ncc.com/index.html'), " bytes\n\n";

# function urlSize -- get the file size
sub urlSize {
    my $result = '';

    # Parse server and request data
    shift  =~ /^http:\/\/(.*?)(\/.*)/;
    my ($http_server,$http_request) = ($1,$2);
    unless ($http_request) { $http_request = '/'; }

    # Set up the socket and make a connection
    my $iaddr = inet_aton($http_server);
    my $paddr = sockaddr_in(80, $iaddr);
    socket(SOCKET, PF_INET, SOCK_STREAM, getprotobyname('tcp'));
    connect(SOCKET, $paddr) || return -1;
    SOCKET->autoflush(1);
    
    # Send the request and store the file
    print SOCKET "GET $http_request HTTP/1.0\r\nHost: $http_server:80\r\n\r\n";
    while(<SOCKET>) { $result .= $_ }
    close(SOCKET);

    # Strip HTTP header and return page lenght
    $result =~ s/^.*\r\n\r\n//s;
    return length $result;
}
